@@ -25,7 +25,6 @@ from tests.const import (
     EXAMPLE_REPO_NAME,
     EXAMPLE_REPO_OWNER,
     MAIN_PROG_NAME,
-    NULL_HEX_SHA,
 )
 from tests.fixtures.example_project import (
     changelog_md_file,
@@ -36,28 +35,31 @@ from tests.fixtures.example_project import (
     example_changelog_rst,
 )
 from tests.fixtures.repos import (
+    get_versions_for_trunk_only_repo_w_no_tags,
+    get_versions_for_trunk_only_repo_w_prerelease_tags,
+    get_versions_for_trunk_only_repo_w_tags,
+    repo_w_git_flow_and_release_channels_angular_commits,
+    repo_w_git_flow_and_release_channels_angular_commits_using_tag_format,
+    repo_w_git_flow_and_release_channels_emoji_commits,
+    repo_w_git_flow_and_release_channels_scipy_commits,
+    repo_w_git_flow_angular_commits,
+    repo_w_git_flow_emoji_commits,
+    repo_w_git_flow_scipy_commits,
+    repo_w_github_flow_w_default_release_channel_angular_commits,
+    repo_w_github_flow_w_default_release_channel_emoji_commits,
+    repo_w_github_flow_w_default_release_channel_scipy_commits,
     repo_w_github_flow_w_feature_release_channel_angular_commits,
     repo_w_github_flow_w_feature_release_channel_emoji_commits,
     repo_w_github_flow_w_feature_release_channel_scipy_commits,
-    repo_with_git_flow_and_release_channels_angular_commits,
-    repo_with_git_flow_and_release_channels_angular_commits_using_tag_format,
-    repo_with_git_flow_and_release_channels_emoji_commits,
-    repo_with_git_flow_and_release_channels_scipy_commits,
-    repo_with_git_flow_angular_commits,
-    repo_with_git_flow_emoji_commits,
-    repo_with_git_flow_scipy_commits,
-    repo_with_no_tags_angular_commits,
-    repo_with_no_tags_emoji_commits,
-    repo_with_no_tags_scipy_commits,
-    repo_with_single_branch_and_prereleases_angular_commits,
-    repo_with_single_branch_and_prereleases_emoji_commits,
-    repo_with_single_branch_and_prereleases_scipy_commits,
-    repo_with_single_branch_angular_commits,
-    repo_with_single_branch_emoji_commits,
-    repo_with_single_branch_scipy_commits,
-)
-from tests.fixtures.repos.trunk_based_dev.repo_w_prereleases import (
-    get_versions_for_trunk_only_repo_w_prerelease_tags,
+    repo_w_no_tags_angular_commits,
+    repo_w_no_tags_emoji_commits,
+    repo_w_no_tags_scipy_commits,
+    repo_w_trunk_only_angular_commits,
+    repo_w_trunk_only_emoji_commits,
+    repo_w_trunk_only_n_prereleases_angular_commits,
+    repo_w_trunk_only_n_prereleases_emoji_commits,
+    repo_w_trunk_only_n_prereleases_scipy_commits,
+    repo_w_trunk_only_scipy_commits,
 )
 from tests.util import (
     add_text_to_file,
@@ -81,46 +83,42 @@ if TYPE_CHECKING:
     )
     from tests.fixtures.git_repo import (
         CommitNReturnChangelogEntryFn,
+        GetCommitDefFn,
         GetVersionStringsFn,
     )
 
 
+@pytest.mark.parametrize("arg0", [None, "--post-to-release-tag"])
 @pytest.mark.parametrize(
-    "repo, tag",
+    "repo, get_version_strings_fn",
     [
-        (lazy_fixture(repo_with_no_tags_angular_commits.__name__), None),
-        *[
-            pytest.param(
-                lazy_fixture(repo_fixture),
-                tag,
-                marks=pytest.mark.comprehensive,
-            )
-            for repo_fixture, tag in (
-                (repo_with_single_branch_angular_commits.__name__, "v0.1.1"),
-                (
-                    repo_with_single_branch_and_prereleases_angular_commits.__name__,
-                    "v0.2.0",
-                ),
-                (
-                    repo_w_github_flow_w_feature_release_channel_angular_commits.__name__,
-                    "v0.2.0",
-                ),
-                (repo_with_git_flow_angular_commits.__name__, "v1.0.0"),
-                (
-                    repo_with_git_flow_and_release_channels_angular_commits.__name__,
-                    "v1.1.0",
-                ),
-            )
-        ],
+        (
+            lazy_fixture(repo_fixture),
+            lazy_fixture(get_versions_fn),
+        )
+        for repo_fixture, get_versions_fn in (
+            # Only need to test when it has tags or no tags
+            # DO NOT need to consider all repo types as it doesn't change no-op behavior
+            (
+                repo_w_no_tags_angular_commits.__name__,
+                get_versions_for_trunk_only_repo_w_no_tags.__name__,
+            ),
+            (
+                repo_w_trunk_only_angular_commits.__name__,
+                get_versions_for_trunk_only_repo_w_tags.__name__,
+            ),
+        )
     ],
 )
-@pytest.mark.parametrize("arg0", [None, "--post-to-release-tag"])
 def test_changelog_noop_is_noop(
     repo: Repo,
-    tag: str | None,
+    get_version_strings_fn: GetVersionStringsFn,
     arg0: str | None,
     cli_runner: CliRunner,
 ):
+    if (version_str := get_version_strings_fn()[-1]) == "Unreleased":
+        version_str = None
+
     repo.git.reset("--hard")
 
     # Set up a requests HTTP session so we can catch the HTTP calls and ensure
@@ -139,7 +137,7 @@ def test_changelog_noop_is_noop(
         get_func_qual_name(semantic_release.hvcs.github.build_requests_session),
         return_value=session,
     ), requests_mock.Mocker(session=session) as mocker:
-        args = [arg0, tag] if tag and arg0 else []
+        args = [arg0, f"v{version_str}"] if version_str and arg0 else []
         cli_cmd = [MAIN_PROG_NAME, "--noop", CHANGELOG_SUBCMD, *args]
         result = cli_runner.invoke(main, cli_cmd[1:])
 
@@ -151,45 +149,6 @@ def test_changelog_noop_is_noop(
         assert not mock_adapter.called
 
 
-@pytest.mark.parametrize(
-    "repo",
-    [
-        *[
-            lazy_fixture(repo_fixture)
-            for repo_fixture in [
-                # All commit types and one without a release
-                repo_with_no_tags_angular_commits.__name__,
-                repo_with_single_branch_angular_commits.__name__,
-                repo_with_single_branch_emoji_commits.__name__,
-                repo_with_single_branch_scipy_commits.__name__,
-            ]
-        ],
-        *[
-            pytest.param(lazy_fixture(repo_fixture), marks=pytest.mark.comprehensive)
-            for repo_fixture in [
-                repo_with_no_tags_angular_commits.__name__,
-                repo_with_no_tags_emoji_commits.__name__,
-                repo_with_no_tags_scipy_commits.__name__,
-                repo_with_single_branch_angular_commits.__name__,
-                repo_with_single_branch_emoji_commits.__name__,
-                repo_with_single_branch_scipy_commits.__name__,
-                repo_with_single_branch_and_prereleases_angular_commits.__name__,
-                repo_with_single_branch_and_prereleases_emoji_commits.__name__,
-                repo_with_single_branch_and_prereleases_scipy_commits.__name__,
-                repo_w_github_flow_w_feature_release_channel_angular_commits.__name__,
-                repo_w_github_flow_w_feature_release_channel_emoji_commits.__name__,
-                repo_w_github_flow_w_feature_release_channel_scipy_commits.__name__,
-                repo_with_git_flow_angular_commits.__name__,
-                repo_with_git_flow_emoji_commits.__name__,
-                repo_with_git_flow_scipy_commits.__name__,
-                repo_with_git_flow_and_release_channels_angular_commits.__name__,
-                repo_with_git_flow_and_release_channels_emoji_commits.__name__,
-                repo_with_git_flow_and_release_channels_scipy_commits.__name__,
-                repo_with_git_flow_and_release_channels_angular_commits_using_tag_format.__name__,
-            ]
-        ],
-    ],
-)
 @pytest.mark.parametrize(
     "changelog_file, insertion_flag",
     [
@@ -205,6 +164,48 @@ def test_changelog_noop_is_noop(
         ),
     ],
 )
+@pytest.mark.parametrize(
+    "repo",
+    [
+        *[
+            lazy_fixture(repo_fixture)
+            for repo_fixture in [
+                # All commit types and one without a release
+                repo_w_no_tags_angular_commits.__name__,
+                repo_w_trunk_only_angular_commits.__name__,
+                repo_w_trunk_only_emoji_commits.__name__,
+                repo_w_trunk_only_scipy_commits.__name__,
+            ]
+        ],
+        *[
+            pytest.param(lazy_fixture(repo_fixture), marks=pytest.mark.comprehensive)
+            for repo_fixture in [
+                # repo_w_no_tags_angular_commits.__name__,
+                repo_w_no_tags_emoji_commits.__name__,
+                repo_w_no_tags_scipy_commits.__name__,
+                # repo_w_trunk_only_angular_commits.__name__,
+                # repo_w_trunk_only_emoji_commits.__name__,
+                # repo_w_trunk_only_scipy_commits.__name__,
+                repo_w_trunk_only_n_prereleases_angular_commits.__name__,
+                repo_w_trunk_only_n_prereleases_emoji_commits.__name__,
+                repo_w_trunk_only_n_prereleases_scipy_commits.__name__,
+                repo_w_github_flow_w_default_release_channel_angular_commits.__name__,
+                repo_w_github_flow_w_default_release_channel_emoji_commits.__name__,
+                repo_w_github_flow_w_default_release_channel_scipy_commits.__name__,
+                repo_w_github_flow_w_feature_release_channel_angular_commits.__name__,
+                repo_w_github_flow_w_feature_release_channel_emoji_commits.__name__,
+                repo_w_github_flow_w_feature_release_channel_scipy_commits.__name__,
+                repo_w_git_flow_angular_commits.__name__,
+                repo_w_git_flow_emoji_commits.__name__,
+                repo_w_git_flow_scipy_commits.__name__,
+                repo_w_git_flow_and_release_channels_angular_commits.__name__,
+                repo_w_git_flow_and_release_channels_emoji_commits.__name__,
+                repo_w_git_flow_and_release_channels_scipy_commits.__name__,
+                repo_w_git_flow_and_release_channels_angular_commits_using_tag_format.__name__,
+            ]
+        ],
+    ],
+)
 def test_changelog_content_regenerated(
     repo: Repo,
     cli_runner: CliRunner,
@@ -249,17 +250,6 @@ def test_changelog_content_regenerated(
     assert expected_changelog_content == actual_content
 
 
-@pytest.mark.parametrize(
-    "repo",
-    [
-        lazy_fixture(repo_fixture)
-        for repo_fixture in [
-            repo_with_single_branch_angular_commits.__name__,
-            repo_with_single_branch_emoji_commits.__name__,
-            repo_with_single_branch_scipy_commits.__name__,
-        ]
-    ],
-)
 @pytest.mark.parametrize(
     "changelog_file",
     [
@@ -267,6 +257,17 @@ def test_changelog_content_regenerated(
         lazy_fixture(example_changelog_rst.__name__),
     ],
 )
+@pytest.mark.parametrize(
+    "repo",
+    [
+        lazy_fixture(repo_fixture)
+        for repo_fixture in [
+            repo_w_trunk_only_angular_commits.__name__,
+            repo_w_trunk_only_emoji_commits.__name__,
+            repo_w_trunk_only_scipy_commits.__name__,
+        ]
+    ],
+)
 def test_changelog_update_mode_unchanged(
     repo: Repo,
     cli_runner: CliRunner,
@@ -306,20 +307,6 @@ def test_changelog_update_mode_unchanged(
     assert expected_changelog_content == actual_content
 
 
-@pytest.mark.parametrize(
-    "repo",
-    [
-        lazy_fixture(repo_fixture)
-        for repo_fixture in [
-            repo_with_no_tags_angular_commits.__name__,
-            repo_with_no_tags_emoji_commits.__name__,
-            repo_with_no_tags_scipy_commits.__name__,
-            repo_with_single_branch_angular_commits.__name__,
-            repo_with_single_branch_emoji_commits.__name__,
-            repo_with_single_branch_scipy_commits.__name__,
-        ]
-    ],
-)
 @pytest.mark.parametrize(
     "changelog_file",
     [
@@ -327,6 +314,20 @@ def test_changelog_update_mode_unchanged(
         lazy_fixture(example_changelog_rst.__name__),
     ],
 )
+@pytest.mark.parametrize(
+    "repo",
+    [
+        lazy_fixture(repo_fixture)
+        for repo_fixture in [
+            repo_w_no_tags_angular_commits.__name__,
+            repo_w_no_tags_emoji_commits.__name__,
+            repo_w_no_tags_scipy_commits.__name__,
+            repo_w_trunk_only_angular_commits.__name__,
+            repo_w_trunk_only_emoji_commits.__name__,
+            repo_w_trunk_only_scipy_commits.__name__,
+        ]
+    ],
+)
 def test_changelog_update_mode_no_prev_changelog(
     repo: Repo,
     cli_runner: CliRunner,
@@ -369,17 +370,6 @@ def test_changelog_update_mode_no_prev_changelog(
     assert expected_changelog_content == actual_content
 
 
-@pytest.mark.parametrize(
-    "repo",
-    [
-        lazy_fixture(repo_fixture)
-        for repo_fixture in [
-            repo_with_single_branch_angular_commits.__name__,
-            repo_with_single_branch_emoji_commits.__name__,
-            repo_with_single_branch_scipy_commits.__name__,
-        ]
-    ],
-)
 @pytest.mark.parametrize(
     "changelog_file, insertion_flag",
     [
@@ -395,6 +385,17 @@ def test_changelog_update_mode_no_prev_changelog(
         ),
     ],
 )
+@pytest.mark.parametrize(
+    "repo",
+    [
+        lazy_fixture(repo_fixture)
+        for repo_fixture in [
+            repo_w_trunk_only_angular_commits.__name__,
+            repo_w_trunk_only_emoji_commits.__name__,
+            repo_w_trunk_only_scipy_commits.__name__,
+        ]
+    ],
+)
 def test_changelog_update_mode_no_flag(
     repo: Repo,
     cli_runner: CliRunner,
@@ -444,18 +445,6 @@ def test_changelog_update_mode_no_flag(
     assert expected_changelog_content == actual_content
 
 
-@pytest.mark.parametrize(
-    "repo",
-    [
-        lazy_fixture(repo_fixture)
-        for repo_fixture in [
-            # MUST HAVE at least 2 tags!
-            repo_with_single_branch_angular_commits.__name__,
-            repo_with_single_branch_emoji_commits.__name__,
-            repo_with_single_branch_scipy_commits.__name__,
-        ]
-    ],
-)
 @pytest.mark.parametrize(
     "changelog_format, changelog_file",
     [
@@ -469,6 +458,18 @@ def test_changelog_update_mode_no_flag(
         ),
     ],
 )
+@pytest.mark.parametrize(
+    "repo",
+    [
+        lazy_fixture(repo_fixture)
+        for repo_fixture in [
+            # MUST HAVE at least 2 tags!
+            repo_w_trunk_only_angular_commits.__name__,
+            repo_w_trunk_only_emoji_commits.__name__,
+            repo_w_trunk_only_scipy_commits.__name__,
+        ]
+    ],
+)
 def test_changelog_update_mode_no_header(
     repo: Repo,
     cli_runner: CliRunner,
@@ -540,18 +541,6 @@ def test_changelog_update_mode_no_header(
     assert expected_changelog_content == actual_content
 
 
-@pytest.mark.parametrize(
-    "repo",
-    [
-        lazy_fixture(repo_fixture)
-        for repo_fixture in [
-            # MUST HAVE at least 2 tags!
-            repo_with_single_branch_angular_commits.__name__,
-            repo_with_single_branch_emoji_commits.__name__,
-            repo_with_single_branch_scipy_commits.__name__,
-        ]
-    ],
-)
 @pytest.mark.parametrize(
     "changelog_format, changelog_file, insertion_flag",
     [
@@ -567,6 +556,18 @@ def test_changelog_update_mode_no_header(
         ),
     ],
 )
+@pytest.mark.parametrize(
+    "repo",
+    [
+        lazy_fixture(repo_fixture)
+        for repo_fixture in [
+            # MUST HAVE at least 2 tags!
+            repo_w_trunk_only_angular_commits.__name__,
+            repo_w_trunk_only_emoji_commits.__name__,
+            repo_w_trunk_only_scipy_commits.__name__,
+        ]
+    ],
+)
 def test_changelog_update_mode_no_footer(
     repo: Repo,
     cli_runner: CliRunner,
@@ -639,18 +640,6 @@ def test_changelog_update_mode_no_footer(
     assert expected_changelog_content == actual_content
 
 
-@pytest.mark.parametrize(
-    "repo",
-    [
-        lazy_fixture(repo_fixture)
-        for repo_fixture in [
-            # Must not have a single release/tag
-            repo_with_no_tags_angular_commits.__name__,
-            repo_with_no_tags_emoji_commits.__name__,
-            repo_with_no_tags_scipy_commits.__name__,
-        ]
-    ],
-)
 @pytest.mark.parametrize(
     "changelog_file, insertion_flag",
     [
@@ -666,6 +655,18 @@ def test_changelog_update_mode_no_footer(
         ),
     ],
 )
+@pytest.mark.parametrize(
+    "repo",
+    [
+        lazy_fixture(repo_fixture)
+        for repo_fixture in [
+            # Must not have a single release/tag
+            repo_w_no_tags_angular_commits.__name__,
+            repo_w_no_tags_emoji_commits.__name__,
+            repo_w_no_tags_scipy_commits.__name__,
+        ]
+    ],
+)
 def test_changelog_update_mode_no_releases(
     repo: Repo,
     cli_runner: CliRunner,
@@ -739,17 +740,6 @@ def test_changelog_update_mode_no_releases(
     assert expected_changelog_content == actual_content
 
 
-@pytest.mark.parametrize(
-    "repo, commit_type",
-    [
-        (lazy_fixture(repo_fixture), repo_fixture.split("_")[-2])
-        for repo_fixture in [
-            repo_with_single_branch_angular_commits.__name__,
-            repo_with_single_branch_emoji_commits.__name__,
-            repo_with_single_branch_scipy_commits.__name__,
-        ]
-    ],
-)
 @pytest.mark.parametrize(
     "changelog_format, changelog_file, insertion_flag",
     [
@@ -765,6 +755,17 @@ def test_changelog_update_mode_no_releases(
         ),
     ],
 )
+@pytest.mark.parametrize(
+    "repo, commit_type",
+    [
+        (lazy_fixture(repo_fixture), repo_fixture.split("_")[-2])
+        for repo_fixture in [
+            repo_w_trunk_only_angular_commits.__name__,
+            repo_w_trunk_only_emoji_commits.__name__,
+            repo_w_trunk_only_scipy_commits.__name__,
+        ]
+    ],
+)
 def test_changelog_update_mode_unreleased_n_released(
     repo: Repo,
     commit_type: str,
@@ -776,6 +777,9 @@ def test_changelog_update_mode_unreleased_n_released(
     commit_n_rtn_changelog_entry: CommitNReturnChangelogEntryFn,
     changelog_file: Path,
     insertion_flag: str,
+    get_commit_def_of_angular_commit: GetCommitDefFn,
+    get_commit_def_of_emoji_commit: GetCommitDefFn,
+    get_commit_def_of_scipy_commit: GetCommitDefFn,
 ):
     """
     Given there are unreleased changes and a previous release in the changelog,
@@ -793,28 +797,19 @@ def test_changelog_update_mode_unreleased_n_released(
 
     commit_n_section = {
         "angular": {
-            "commit": {
-                "msg": "perf: improve the performance of the application",
-                "sha": NULL_HEX_SHA,
-            },
+            "commit": get_commit_def_of_angular_commit(
+                "perf: improve the performance of the application"
+            ),
             "section": "Performance Improvements",
         },
         "emoji": {
-            "commit": {
-                "msg": ":zap: improve the performance of the application",
-                "sha": NULL_HEX_SHA,
-            },
+            "commit": get_commit_def_of_emoji_commit(
+                ":zap: improve the performance of the application"
+            ),
             "section": ":zap:",
         },
         "scipy": {
-            "commit": {"msg": "MAINT: fix an issue", "sha": NULL_HEX_SHA},
-            "section": "Fix",
-        },
-        "tag": {
-            "commit": {
-                "msg": ":nut_and_bolt: improve the performance of the application",
-                "sha": NULL_HEX_SHA,
-            },
+            "commit": get_commit_def_of_scipy_commit("MAINT: fix an issue"),
             "section": "Fix",
         },
     }
@@ -853,7 +848,8 @@ def test_changelog_update_mode_unreleased_n_released(
 
             ### {commit_n_section[commit_type]["section"]}
 
-            * {unreleased_commit_entry['msg']} ([`{unreleased_commit_entry['sha'][:7]}`]({hvcs.commit_hash_url(unreleased_commit_entry['sha'])}))
+            - {unreleased_commit_entry['desc'].capitalize()}
+              ([`{unreleased_commit_entry['sha'][:7]}`]({hvcs.commit_hash_url(unreleased_commit_entry['sha'])}))
             """
         ),
         ChangelogOutputFormat.RESTRUCTURED_TEXT: dedent(
@@ -866,7 +862,7 @@ def test_changelog_update_mode_unreleased_n_released(
             {commit_n_section[commit_type]["section"]}
             {"-" * len(commit_n_section[commit_type]["section"])}
 
-            * {unreleased_commit_entry['msg']} (`{unreleased_commit_entry['sha'][:7]}`_)
+            * {unreleased_commit_entry['desc'].capitalize()} (`{unreleased_commit_entry['sha'][:7]}`_)
 
             .. _{unreleased_commit_entry['sha'][:7]}: {hvcs.commit_hash_url(unreleased_commit_entry['sha'])}
             """
@@ -919,9 +915,7 @@ def test_changelog_update_mode_unreleased_n_released(
 
 
 # Just need to test that it works for "a" project, not all
-@pytest.mark.usefixtures(
-    repo_with_single_branch_and_prereleases_angular_commits.__name__
-)
+@pytest.mark.usefixtures(repo_w_trunk_only_n_prereleases_angular_commits.__name__)
 @pytest.mark.parametrize(
     "args", [("--post-to-release-tag", "v1.99.91910000000000000000000000000")]
 )
@@ -938,9 +932,7 @@ def test_changelog_release_tag_not_in_history(
     assert "not in release history" in result.stderr.lower()
 
 
-@pytest.mark.usefixtures(
-    repo_with_single_branch_and_prereleases_angular_commits.__name__
-)
+@pytest.mark.usefixtures(repo_w_trunk_only_n_prereleases_angular_commits.__name__)
 @pytest.mark.parametrize("args", [("--post-to-release-tag", "v0.1.0")])
 def test_changelog_post_to_release(args: list[str], cli_runner: CliRunner):
     # Set up a requests HTTP session so we can catch the HTTP calls and ensure they're
@@ -1028,9 +1020,7 @@ def test_changelog_post_to_release(args: list[str], cli_runner: CliRunner):
     "repo, get_version_strings",
     [
         (
-            lazy_fixture(
-                repo_with_single_branch_and_prereleases_angular_commits.__name__
-            ),
+            lazy_fixture(repo_w_trunk_only_n_prereleases_angular_commits.__name__),
             lazy_fixture(get_versions_for_trunk_only_repo_w_prerelease_tags.__name__),
         ),
     ],
@@ -1080,7 +1070,7 @@ def test_custom_release_notes_template(
     assert expected_release_notes == actual_notes
 
 
-@pytest.mark.usefixtures(repo_with_single_branch_angular_commits.__name__)
+@pytest.mark.usefixtures(repo_w_trunk_only_angular_commits.__name__)
 def test_changelog_default_on_empty_template_dir(
     example_changelog_md: Path,
     changelog_template_dir: Path,
@@ -1111,7 +1101,7 @@ def test_changelog_default_on_empty_template_dir(
     assert example_changelog_md.exists()
 
 
-@pytest.mark.usefixtures(repo_with_single_branch_angular_commits.__name__)
+@pytest.mark.usefixtures(repo_w_trunk_only_angular_commits.__name__)
 def test_changelog_default_on_incorrect_config_template_file(
     example_changelog_md: Path,
     changelog_template_dir: Path,
@@ -1144,7 +1134,7 @@ def test_changelog_default_on_incorrect_config_template_file(
 
 
 @pytest.mark.parametrize("bad_changelog_file_str", ("/etc/passwd", "../../.ssh/id_rsa"))
-@pytest.mark.usefixtures(repo_with_single_branch_angular_commits.__name__)
+@pytest.mark.usefixtures(repo_w_trunk_only_angular_commits.__name__)
 def test_changelog_prevent_malicious_path_traversal_file(
     update_pyproject_toml: UpdatePyprojectTomlFn,
     bad_changelog_file_str: str,
@@ -1169,7 +1159,7 @@ def test_changelog_prevent_malicious_path_traversal_file(
 
 
 @pytest.mark.parametrize("template_dir_path", ("~/.ssh", "../../.ssh"))
-@pytest.mark.usefixtures(repo_with_single_branch_angular_commits.__name__)
+@pytest.mark.usefixtures(repo_w_trunk_only_angular_commits.__name__)
 def test_changelog_prevent_external_path_traversal_dir(
     update_pyproject_toml: UpdatePyprojectTomlFn,
     template_dir_path: str,
