@@ -18,25 +18,28 @@ from tests.fixtures.example_project import (
     example_changelog_rst,
 )
 from tests.fixtures.repos import (
+    repo_w_git_flow_and_release_channels_angular_commits,
+    repo_w_git_flow_and_release_channels_angular_commits_using_tag_format,
+    repo_w_git_flow_and_release_channels_emoji_commits,
+    repo_w_git_flow_and_release_channels_scipy_commits,
+    repo_w_git_flow_angular_commits,
+    repo_w_git_flow_emoji_commits,
+    repo_w_git_flow_scipy_commits,
+    repo_w_github_flow_w_default_release_channel_angular_commits,
+    repo_w_github_flow_w_default_release_channel_emoji_commits,
+    repo_w_github_flow_w_default_release_channel_scipy_commits,
     repo_w_github_flow_w_feature_release_channel_angular_commits,
     repo_w_github_flow_w_feature_release_channel_emoji_commits,
     repo_w_github_flow_w_feature_release_channel_scipy_commits,
-    repo_with_git_flow_and_release_channels_angular_commits,
-    repo_with_git_flow_and_release_channels_angular_commits_using_tag_format,
-    repo_with_git_flow_and_release_channels_emoji_commits,
-    repo_with_git_flow_and_release_channels_scipy_commits,
-    repo_with_git_flow_angular_commits,
-    repo_with_git_flow_emoji_commits,
-    repo_with_git_flow_scipy_commits,
-    repo_with_no_tags_angular_commits,
-    repo_with_no_tags_emoji_commits,
-    repo_with_no_tags_scipy_commits,
-    repo_with_single_branch_and_prereleases_angular_commits,
-    repo_with_single_branch_and_prereleases_emoji_commits,
-    repo_with_single_branch_and_prereleases_scipy_commits,
-    repo_with_single_branch_angular_commits,
-    repo_with_single_branch_emoji_commits,
-    repo_with_single_branch_scipy_commits,
+    repo_w_no_tags_angular_commits,
+    repo_w_no_tags_emoji_commits,
+    repo_w_no_tags_scipy_commits,
+    repo_w_trunk_only_angular_commits,
+    repo_w_trunk_only_emoji_commits,
+    repo_w_trunk_only_n_prereleases_angular_commits,
+    repo_w_trunk_only_n_prereleases_emoji_commits,
+    repo_w_trunk_only_n_prereleases_scipy_commits,
+    repo_w_trunk_only_scipy_commits,
 )
 from tests.util import assert_successful_exit_code
 
@@ -47,37 +50,9 @@ if TYPE_CHECKING:
     from git import Repo
 
     from tests.fixtures.example_project import UpdatePyprojectTomlFn
-    from tests.fixtures.git_repo import GetRepoDefinitionFn
+    from tests.fixtures.git_repo import CommitConvention, GetRepoDefinitionFn
 
 
-@pytest.mark.parametrize(
-    "repo",
-    [
-        lazy_fixture(repo_with_single_branch_angular_commits.__name__),
-        *[
-            pytest.param(lazy_fixture(repo_fixture), marks=pytest.mark.comprehensive)
-            for repo_fixture in [
-                # Must have a previous release/tag
-                # repo_with_single_branch_angular_commits.__name__, # default
-                repo_with_single_branch_emoji_commits.__name__,
-                repo_with_single_branch_scipy_commits.__name__,
-                repo_with_single_branch_and_prereleases_angular_commits.__name__,
-                repo_with_single_branch_and_prereleases_emoji_commits.__name__,
-                repo_with_single_branch_and_prereleases_scipy_commits.__name__,
-                repo_w_github_flow_w_feature_release_channel_angular_commits.__name__,
-                repo_w_github_flow_w_feature_release_channel_emoji_commits.__name__,
-                repo_w_github_flow_w_feature_release_channel_scipy_commits.__name__,
-                repo_with_git_flow_angular_commits.__name__,
-                repo_with_git_flow_emoji_commits.__name__,
-                repo_with_git_flow_scipy_commits.__name__,
-                repo_with_git_flow_and_release_channels_angular_commits.__name__,
-                repo_with_git_flow_and_release_channels_emoji_commits.__name__,
-                repo_with_git_flow_and_release_channels_scipy_commits.__name__,
-                repo_with_git_flow_and_release_channels_angular_commits_using_tag_format.__name__,
-            ]
-        ],
-    ],
-)
 @pytest.mark.parametrize(
     "changelog_file, insertion_flag",
     [
@@ -93,6 +68,37 @@ if TYPE_CHECKING:
         ),
     ],
 )
+@pytest.mark.parametrize(
+    "repo",
+    [
+        lazy_fixture(repo_w_trunk_only_angular_commits.__name__),
+        *[
+            pytest.param(lazy_fixture(repo_fixture), marks=pytest.mark.comprehensive)
+            for repo_fixture in [
+                # Must have a previous release/tag
+                # repo_with_single_branch_angular_commits.__name__, # default
+                repo_w_trunk_only_emoji_commits.__name__,
+                repo_w_trunk_only_scipy_commits.__name__,
+                repo_w_trunk_only_n_prereleases_angular_commits.__name__,
+                repo_w_trunk_only_n_prereleases_emoji_commits.__name__,
+                repo_w_trunk_only_n_prereleases_scipy_commits.__name__,
+                repo_w_github_flow_w_default_release_channel_angular_commits.__name__,
+                repo_w_github_flow_w_default_release_channel_emoji_commits.__name__,
+                repo_w_github_flow_w_default_release_channel_scipy_commits.__name__,
+                repo_w_github_flow_w_feature_release_channel_angular_commits.__name__,
+                repo_w_github_flow_w_feature_release_channel_emoji_commits.__name__,
+                repo_w_github_flow_w_feature_release_channel_scipy_commits.__name__,
+                repo_w_git_flow_angular_commits.__name__,
+                repo_w_git_flow_emoji_commits.__name__,
+                repo_w_git_flow_scipy_commits.__name__,
+                repo_w_git_flow_and_release_channels_angular_commits.__name__,
+                repo_w_git_flow_and_release_channels_emoji_commits.__name__,
+                repo_w_git_flow_and_release_channels_scipy_commits.__name__,
+                repo_w_git_flow_and_release_channels_angular_commits_using_tag_format.__name__,
+            ]
+        ],
+    ],
+)
 def test_version_updates_changelog_w_new_version(
     repo: Repo,
     update_pyproject_toml: UpdatePyprojectTomlFn,
@@ -169,21 +175,6 @@ def test_version_updates_changelog_w_new_version(
     assert expected_changelog_content == actual_content
 
 
-@pytest.mark.parametrize(
-    "repo",
-    [
-        lazy_fixture(repo_with_no_tags_angular_commits.__name__),
-        *[
-            pytest.param(lazy_fixture(repo_fixture), marks=pytest.mark.comprehensive)
-            for repo_fixture in [
-                # Must not have a single release/tag
-                # repo_with_no_tags_angular_commits.__name__, # default
-                repo_with_no_tags_emoji_commits.__name__,
-                repo_with_no_tags_scipy_commits.__name__,
-            ]
-        ],
-    ],
-)
 @pytest.mark.parametrize(
     "changelog_format, changelog_file, insertion_flag",
     [
@@ -199,6 +190,21 @@ def test_version_updates_changelog_w_new_version(
         ),
     ],
 )
+@pytest.mark.parametrize(
+    "repo",
+    [
+        lazy_fixture(repo_w_no_tags_angular_commits.__name__),
+        *[
+            pytest.param(lazy_fixture(repo_fixture), marks=pytest.mark.comprehensive)
+            for repo_fixture in [
+                # Must not have a single release/tag
+                # repo_with_no_tags_angular_commits.__name__, # default
+                repo_w_no_tags_emoji_commits.__name__,
+                repo_w_no_tags_scipy_commits.__name__,
+            ]
+        ],
+    ],
+)
 def test_version_updates_changelog_wo_prev_releases(
     repo: Repo,
     cli_runner: CliRunner,
@@ -304,41 +310,44 @@ def test_version_updates_changelog_wo_prev_releases(
     assert expected_changelog_content == actual_content
 
 
+@pytest.mark.parametrize(
+    "changelog_file",
+    [
+        lazy_fixture(example_changelog_md.__name__),
+        lazy_fixture(example_changelog_rst.__name__),
+    ],
+)
 @pytest.mark.parametrize(
     "repo",
     [
-        lazy_fixture(repo_with_single_branch_angular_commits.__name__),
+        lazy_fixture(repo_w_trunk_only_angular_commits.__name__),
         *[
             pytest.param(lazy_fixture(repo_fixture), marks=pytest.mark.comprehensive)
             for repo_fixture in [
                 # Must have a previous release/tag
                 # repo_with_single_branch_angular_commits.__name__, # default
-                repo_with_single_branch_emoji_commits.__name__,
-                repo_with_single_branch_scipy_commits.__name__,
-                repo_with_single_branch_and_prereleases_angular_commits.__name__,
-                repo_with_single_branch_and_prereleases_emoji_commits.__name__,
-                repo_with_single_branch_and_prereleases_scipy_commits.__name__,
+                repo_w_trunk_only_emoji_commits.__name__,
+                repo_w_trunk_only_scipy_commits.__name__,
+                repo_w_trunk_only_n_prereleases_angular_commits.__name__,
+                repo_w_trunk_only_n_prereleases_emoji_commits.__name__,
+                repo_w_trunk_only_n_prereleases_scipy_commits.__name__,
+                repo_w_github_flow_w_default_release_channel_angular_commits.__name__,
+                repo_w_github_flow_w_default_release_channel_emoji_commits.__name__,
+                repo_w_github_flow_w_default_release_channel_scipy_commits.__name__,
                 repo_w_github_flow_w_feature_release_channel_angular_commits.__name__,
                 repo_w_github_flow_w_feature_release_channel_emoji_commits.__name__,
                 repo_w_github_flow_w_feature_release_channel_scipy_commits.__name__,
-                repo_with_git_flow_angular_commits.__name__,
-                repo_with_git_flow_emoji_commits.__name__,
-                repo_with_git_flow_scipy_commits.__name__,
-                repo_with_git_flow_and_release_channels_angular_commits.__name__,
-                repo_with_git_flow_and_release_channels_emoji_commits.__name__,
-                repo_with_git_flow_and_release_channels_scipy_commits.__name__,
-                repo_with_git_flow_and_release_channels_angular_commits_using_tag_format.__name__,
+                repo_w_git_flow_angular_commits.__name__,
+                repo_w_git_flow_emoji_commits.__name__,
+                repo_w_git_flow_scipy_commits.__name__,
+                repo_w_git_flow_and_release_channels_angular_commits.__name__,
+                repo_w_git_flow_and_release_channels_emoji_commits.__name__,
+                repo_w_git_flow_and_release_channels_scipy_commits.__name__,
+                repo_w_git_flow_and_release_channels_angular_commits_using_tag_format.__name__,
             ]
         ],
     ],
 )
-@pytest.mark.parametrize(
-    "changelog_file",
-    [
-        lazy_fixture(example_changelog_md.__name__),
-        lazy_fixture(example_changelog_rst.__name__),
-    ],
-)
 def test_version_initializes_changelog_in_update_mode_w_no_prev_changelog(
     repo: Repo,
     cli_runner: CliRunner,
@@ -400,7 +409,7 @@ def test_version_initializes_changelog_in_update_mode_w_no_prev_changelog(
         ),
     ],
 )
-@pytest.mark.usefixtures(repo_with_single_branch_angular_commits.__name__)
+@pytest.mark.usefixtures(repo_w_trunk_only_angular_commits.__name__)
 def test_version_maintains_changelog_in_update_mode_w_no_flag(
     changelog_file: Path,
     cli_runner: CliRunner,
@@ -449,16 +458,6 @@ def test_version_maintains_changelog_in_update_mode_w_no_flag(
     assert expected_changelog_content == actual_content
 
 
-@pytest.mark.parametrize(
-    "repo, commit_type",
-    [
-        (lazy_fixture(repo_fixture), repo_fixture.split("_")[-2])
-        for repo_fixture in [
-            # Must have a previous release/tag
-            repo_with_single_branch_angular_commits.__name__,
-        ]
-    ],
-)
 @pytest.mark.parametrize(
     "changelog_file",
     [
@@ -466,9 +465,19 @@ def test_version_maintains_changelog_in_update_mode_w_no_flag(
         lazy_fixture(example_changelog_rst.__name__),
     ],
 )
+@pytest.mark.parametrize(
+    "repo, commit_type",
+    [
+        (lazy_fixture(repo_fixture), repo_fixture.split("_")[-2])
+        for repo_fixture in [
+            # Must have a previous release/tag
+            repo_w_trunk_only_angular_commits.__name__,
+        ]
+    ],
+)
 def test_version_updates_changelog_w_new_version_n_filtered_commit(
     repo: Repo,
-    commit_type: str,
+    commit_type: CommitConvention,
     update_pyproject_toml: UpdatePyprojectTomlFn,
     cli_runner: CliRunner,
     changelog_file: Path,
@@ -483,7 +492,9 @@ def test_version_updates_changelog_w_new_version_n_filtered_commit(
     repo_definition = get_commits_for_trunk_only_repo_w_tags(commit_type)
 
     # expected version bump commit (that should be in changelog)
-    expected_bump_message = list(repo_definition.values())[-1]["commits"][-1]["msg"]
+    expected_bump_message = list(repo_definition.values())[-1]["commits"][-1][
+        "desc"
+    ].capitalize()
 
     # Capture the expected changelog content
     expected_changelog_content = changelog_file.read_text()
