@@ -1,6 +1,5 @@
 from __future__ import annotations
 
-from copy import deepcopy
 from typing import TYPE_CHECKING
 
 import pytest
@@ -8,7 +7,7 @@ from git import Repo
 
 from semantic_release.cli.config import ChangelogOutputFormat
 
-from tests.const import EXAMPLE_HVCS_DOMAIN, NULL_HEX_SHA
+from tests.const import DEFAULT_BRANCH_NAME, EXAMPLE_HVCS_DOMAIN, INITIAL_COMMIT_MESSAGE
 from tests.util import copy_dir_tree, temporary_working_directory
 
 if TYPE_CHECKING:
@@ -22,8 +21,11 @@ if TYPE_CHECKING:
         BaseRepoVersionDef,
         BuildRepoFn,
         CommitConvention,
+        CreateMergeCommitFn,
         CreateReleaseFn,
         ExProjectGitRepoFn,
+        ExtractRepoDefinitionFn,
+        FormatGitMergeCommitMsgFn,
         GetRepoDefinitionFn,
         GetVersionStringsFn,
         RepoDefinition,
@@ -34,20 +36,40 @@ if TYPE_CHECKING:
     )
 
 
+DEV_BRANCH_NAME = "dev"
+FEAT_BRANCH_1_NAME = "feat/feature-1"
+FEAT_BRANCH_2_NAME = "feat/feature-2"
+FEAT_BRANCH_3_NAME = "feat/feature-3"
+FEAT_BRANCH_4_NAME = "feat/feature-4"
+FIX_BRANCH_1_NAME = "fix/patch-1"
+FIX_BRANCH_2_NAME = "fix/patch-2"
+
+
 @pytest.fixture(scope="session")
-def get_commits_for_git_flow_repo_w_3_release_channels() -> GetRepoDefinitionFn:
+def get_commits_for_git_flow_repo_w_3_release_channels(
+    extract_commit_convention_from_base_repo_def: ExtractRepoDefinitionFn,
+    format_merge_commit_msg_git: FormatGitMergeCommitMsgFn,
+) -> GetRepoDefinitionFn:
     base_definition: dict[str, BaseRepoVersionDef] = {
         "0.1.0": {
             "changelog_sections": {
-                "angular": [{"section": "Unknown", "i_commits": [0]}],
-                "emoji": [{"section": "Other", "i_commits": [0]}],
-                "scipy": [{"section": "Unknown", "i_commits": [0]}],
+                "angular": [{"section": "Features", "i_commits": [1]}],
+                "emoji": [
+                    {"section": ":sparkles:", "i_commits": [1]},
+                    {"section": "Other", "i_commits": [0]},
+                ],
+                "scipy": [{"section": "Feature", "i_commits": [1]}],
             },
             "commits": [
                 {
-                    "angular": {"msg": "Initial commit", "sha": NULL_HEX_SHA},
-                    "emoji": {"msg": "Initial commit", "sha": NULL_HEX_SHA},
-                    "scipy": {"msg": "Initial commit", "sha": NULL_HEX_SHA},
+                    "angular": INITIAL_COMMIT_MESSAGE,
+                    "emoji": INITIAL_COMMIT_MESSAGE,
+                    "scipy": INITIAL_COMMIT_MESSAGE,
+                },
+                {
+                    "angular": "feat: add new feature",
+                    "emoji": ":sparkles: add new feature",
+                    "scipy": "ENH: add new feature",
                 },
             ],
         },
@@ -59,17 +81,16 @@ def get_commits_for_git_flow_repo_w_3_release_channels() -> GetRepoDefinitionFn:
             },
             "commits": [
                 {
-                    "angular": {"msg": "fix: correct some text", "sha": NULL_HEX_SHA},
-                    "emoji": {"msg": ":bug: correct some text", "sha": NULL_HEX_SHA},
-                    "scipy": {"msg": "MAINT: correct some text", "sha": NULL_HEX_SHA},
+                    "angular": "fix: correct some text",
+                    "emoji": ":bug: correct some text",
+                    "scipy": "MAINT: correct some text",
                 }
             ],
         },
         "1.0.0-rc.1": {
             "changelog_sections": {
                 "angular": [
-                    {"section": "Breaking", "i_commits": [0]},
-                    {"section": "Unknown", "i_commits": [1]},
+                    {"section": "Features", "i_commits": [0]},
                 ],
                 "emoji": [
                     {"section": ":boom:", "i_commits": [0]},
@@ -77,37 +98,27 @@ def get_commits_for_git_flow_repo_w_3_release_channels() -> GetRepoDefinitionFn:
                 ],
                 "scipy": [
                     {"section": "Breaking", "i_commits": [0]},
-                    {"section": "Unknown", "i_commits": [1]},
                 ],
             },
             "commits": [
                 {
-                    "angular": {
-                        "msg": "feat!: add revolutionary feature",
-                        "sha": NULL_HEX_SHA,
-                    },
-                    "emoji": {
-                        "msg": ":boom: add revolutionary feature",
-                        "sha": NULL_HEX_SHA,
-                    },
-                    "scipy": {
-                        "msg": "API: add revolutionary feature",
-                        "sha": NULL_HEX_SHA,
-                    },
+                    "angular": "feat!: add revolutionary feature\n\nBREAKING CHANGE: this is a breaking change",
+                    "emoji": ":boom: add revolutionary feature\n\nThis change is a breaking change",
+                    "scipy": "API: add revolutionary feature\n\nBREAKING CHANGE: this is a breaking change",
                 },
                 {
-                    "angular": {
-                        "msg": "Merge branch 'feat/feature-1' into 'dev'",
-                        "sha": NULL_HEX_SHA,
-                    },
-                    "emoji": {
-                        "msg": "Merge branch 'feat/feature-1' into 'dev'",
-                        "sha": NULL_HEX_SHA,
-                    },
-                    "scipy": {
-                        "msg": "Merge branch 'feat/feature-1' into 'dev'",
-                        "sha": NULL_HEX_SHA,
-                    },
+                    "angular": format_merge_commit_msg_git(
+                        branch_name=FEAT_BRANCH_1_NAME,
+                        tgt_branch_name=DEV_BRANCH_NAME,
+                    ),
+                    "emoji": format_merge_commit_msg_git(
+                        branch_name=FEAT_BRANCH_1_NAME,
+                        tgt_branch_name=DEV_BRANCH_NAME,
+                    ),
+                    "scipy": format_merge_commit_msg_git(
+                        branch_name=FEAT_BRANCH_1_NAME,
+                        tgt_branch_name=DEV_BRANCH_NAME,
+                    ),
                 },
             ],
         },
@@ -115,7 +126,6 @@ def get_commits_for_git_flow_repo_w_3_release_channels() -> GetRepoDefinitionFn:
             "changelog_sections": {
                 "angular": [
                     {"section": "Features", "i_commits": [0]},
-                    {"section": "Unknown", "i_commits": [2, 1]},
                 ],
                 "emoji": [
                     {"section": ":sparkles:", "i_commits": [0]},
@@ -123,45 +133,41 @@ def get_commits_for_git_flow_repo_w_3_release_channels() -> GetRepoDefinitionFn:
                 ],
                 "scipy": [
                     {"section": "Feature", "i_commits": [0]},
-                    {"section": "Unknown", "i_commits": [2, 1]},
                 ],
             },
             "commits": [
                 {
-                    "angular": {"msg": "feat: add some more text", "sha": NULL_HEX_SHA},
-                    "emoji": {
-                        "msg": ":sparkles: add some more text",
-                        "sha": NULL_HEX_SHA,
-                    },
-                    "scipy": {"msg": "ENH: add some more text", "sha": NULL_HEX_SHA},
+                    "angular": "feat: add some more text",
+                    "emoji": ":sparkles: add some more text",
+                    "scipy": "ENH: add some more text",
                 },
                 {
-                    "angular": {
-                        "msg": "Merge branch 'feat/feature-2' into 'dev'",
-                        "sha": NULL_HEX_SHA,
-                    },
-                    "emoji": {
-                        "msg": "Merge branch 'feat/feature-2' into 'dev'",
-                        "sha": NULL_HEX_SHA,
-                    },
-                    "scipy": {
-                        "msg": "Merge branch 'feat/feature-2' into 'dev'",
-                        "sha": NULL_HEX_SHA,
-                    },
+                    "angular": format_merge_commit_msg_git(
+                        branch_name=FEAT_BRANCH_2_NAME,
+                        tgt_branch_name=DEV_BRANCH_NAME,
+                    ),
+                    "emoji": format_merge_commit_msg_git(
+                        branch_name=FEAT_BRANCH_2_NAME,
+                        tgt_branch_name=DEV_BRANCH_NAME,
+                    ),
+                    "scipy": format_merge_commit_msg_git(
+                        branch_name=FEAT_BRANCH_2_NAME,
+                        tgt_branch_name=DEV_BRANCH_NAME,
+                    ),
                 },
                 {
-                    "angular": {
-                        "msg": "Merge branch 'dev' into 'main'",
-                        "sha": NULL_HEX_SHA,
-                    },
-                    "emoji": {
-                        "msg": "Merge branch 'dev' into 'main'",
-                        "sha": NULL_HEX_SHA,
-                    },
-                    "scipy": {
-                        "msg": "Merge branch 'dev' into 'main'",
-                        "sha": NULL_HEX_SHA,
-                    },
+                    "angular": format_merge_commit_msg_git(
+                        branch_name=DEV_BRANCH_NAME,
+                        tgt_branch_name=DEFAULT_BRANCH_NAME,
+                    ),
+                    "emoji": format_merge_commit_msg_git(
+                        branch_name=DEV_BRANCH_NAME,
+                        tgt_branch_name=DEFAULT_BRANCH_NAME,
+                    ),
+                    "scipy": format_merge_commit_msg_git(
+                        branch_name=DEV_BRANCH_NAME,
+                        tgt_branch_name=DEFAULT_BRANCH_NAME,
+                    ),
                 },
             ],
         },
@@ -173,18 +179,9 @@ def get_commits_for_git_flow_repo_w_3_release_channels() -> GetRepoDefinitionFn:
             },
             "commits": [
                 {
-                    "angular": {
-                        "msg": "feat(dev): add some more text",
-                        "sha": NULL_HEX_SHA,
-                    },
-                    "emoji": {
-                        "msg": ":sparkles: (dev) add some more text",
-                        "sha": NULL_HEX_SHA,
-                    },
-                    "scipy": {
-                        "msg": "ENH(dev): add some more text",
-                        "sha": NULL_HEX_SHA,
-                    },
+                    "angular": "feat(dev): add some more text",
+                    "emoji": ":sparkles: (dev) add some more text",
+                    "scipy": "ENH(dev): add some more text",
                 },
             ],
         },
@@ -196,18 +193,9 @@ def get_commits_for_git_flow_repo_w_3_release_channels() -> GetRepoDefinitionFn:
             },
             "commits": [
                 {
-                    "angular": {
-                        "msg": "feat(dev): add some more text",
-                        "sha": NULL_HEX_SHA,
-                    },
-                    "emoji": {
-                        "msg": ":sparkles: (dev) add some more text",
-                        "sha": NULL_HEX_SHA,
-                    },
-                    "scipy": {
-                        "msg": "ENH(dev): add some more text",
-                        "sha": NULL_HEX_SHA,
-                    },
+                    "angular": "feat(dev): add some more text",
+                    "emoji": ":sparkles: (dev) add some more text",
+                    "scipy": "ENH(dev): add some more text",
                 },
             ],
         },
@@ -215,7 +203,6 @@ def get_commits_for_git_flow_repo_w_3_release_channels() -> GetRepoDefinitionFn:
             "changelog_sections": {
                 "angular": [
                     {"section": "Bug Fixes", "i_commits": [1]},
-                    {"section": "Unknown", "i_commits": [2, 0]},
                 ],
                 "emoji": [
                     {"section": ":bug:", "i_commits": [1]},
@@ -223,51 +210,41 @@ def get_commits_for_git_flow_repo_w_3_release_channels() -> GetRepoDefinitionFn:
                 ],
                 "scipy": [
                     {"section": "Fix", "i_commits": [1]},
-                    {"section": "Unknown", "i_commits": [2, 0]},
                 ],
             },
             "commits": [
                 {
-                    "angular": {
-                        "msg": "Merge branch 'feat/feature-3' into 'dev'",
-                        "sha": NULL_HEX_SHA,
-                    },
-                    "emoji": {
-                        "msg": "Merge branch 'feat/feature-3' into 'dev'",
-                        "sha": NULL_HEX_SHA,
-                    },
-                    "scipy": {
-                        "msg": "Merge branch 'feat/feature-3' into 'dev'",
-                        "sha": NULL_HEX_SHA,
-                    },
+                    "angular": format_merge_commit_msg_git(
+                        branch_name=FEAT_BRANCH_3_NAME,
+                        tgt_branch_name=DEV_BRANCH_NAME,
+                    ),
+                    "emoji": format_merge_commit_msg_git(
+                        branch_name=FEAT_BRANCH_3_NAME,
+                        tgt_branch_name=DEV_BRANCH_NAME,
+                    ),
+                    "scipy": format_merge_commit_msg_git(
+                        branch_name=FEAT_BRANCH_3_NAME,
+                        tgt_branch_name=DEV_BRANCH_NAME,
+                    ),
                 },
                 {
-                    "angular": {
-                        "msg": "fix(dev): correct some text",
-                        "sha": NULL_HEX_SHA,
-                    },
-                    "emoji": {
-                        "msg": ":bug: correct dev-scoped text",
-                        "sha": NULL_HEX_SHA,
-                    },
-                    "scipy": {
-                        "msg": "MAINT(dev): correct some text",
-                        "sha": NULL_HEX_SHA,
-                    },
+                    "angular": "fix(dev): correct some text",
+                    "emoji": ":bug: correct dev-scoped text",
+                    "scipy": "MAINT(dev): correct some text",
                 },
                 {
-                    "angular": {
-                        "msg": "Merge branch 'fix/patch-1' into 'dev'",
-                        "sha": NULL_HEX_SHA,
-                    },
-                    "emoji": {
-                        "msg": "Merge branch 'fix/patch-1' into 'dev'",
-                        "sha": NULL_HEX_SHA,
-                    },
-                    "scipy": {
-                        "msg": "Merge branch 'fix/patch-1' into 'dev'",
-                        "sha": NULL_HEX_SHA,
-                    },
+                    "angular": format_merge_commit_msg_git(
+                        branch_name=FIX_BRANCH_1_NAME,
+                        tgt_branch_name=DEV_BRANCH_NAME,
+                    ),
+                    "emoji": format_merge_commit_msg_git(
+                        branch_name=FIX_BRANCH_1_NAME,
+                        tgt_branch_name=DEV_BRANCH_NAME,
+                    ),
+                    "scipy": format_merge_commit_msg_git(
+                        branch_name=FIX_BRANCH_1_NAME,
+                        tgt_branch_name=DEV_BRANCH_NAME,
+                    ),
                 },
             ],
         },
@@ -275,7 +252,6 @@ def get_commits_for_git_flow_repo_w_3_release_channels() -> GetRepoDefinitionFn:
             "changelog_sections": {
                 "angular": [
                     {"section": "Features", "i_commits": [0]},
-                    {"section": "Unknown", "i_commits": [1]},
                 ],
                 "emoji": [
                     {"section": ":sparkles:", "i_commits": [0]},
@@ -283,37 +259,27 @@ def get_commits_for_git_flow_repo_w_3_release_channels() -> GetRepoDefinitionFn:
                 ],
                 "scipy": [
                     {"section": "Feature", "i_commits": [0]},
-                    {"section": "Unknown", "i_commits": [1]},
                 ],
             },
             "commits": [
                 {
-                    "angular": {
-                        "msg": "feat(scope): add some more text",
-                        "sha": NULL_HEX_SHA,
-                    },
-                    "emoji": {
-                        "msg": ":sparkles: add scoped change",
-                        "sha": NULL_HEX_SHA,
-                    },
-                    "scipy": {
-                        "msg": "ENH(scope): add some more text",
-                        "sha": NULL_HEX_SHA,
-                    },
+                    "angular": "feat(scope): add some more text",
+                    "emoji": ":sparkles: add scoped change",
+                    "scipy": "ENH(scope): add some more text",
                 },
                 {
-                    "angular": {
-                        "msg": "Merge branch 'feat/feature-4' into 'dev'",
-                        "sha": NULL_HEX_SHA,
-                    },
-                    "emoji": {
-                        "msg": "Merge branch 'feat/feature-4' into 'dev'",
-                        "sha": NULL_HEX_SHA,
-                    },
-                    "scipy": {
-                        "msg": "Merge branch 'feat/feature-4' into 'dev'",
-                        "sha": NULL_HEX_SHA,
-                    },
+                    "angular": format_merge_commit_msg_git(
+                        branch_name=FEAT_BRANCH_4_NAME,
+                        tgt_branch_name=DEV_BRANCH_NAME,
+                    ),
+                    "emoji": format_merge_commit_msg_git(
+                        branch_name=FEAT_BRANCH_4_NAME,
+                        tgt_branch_name=DEV_BRANCH_NAME,
+                    ),
+                    "scipy": format_merge_commit_msg_git(
+                        branch_name=FEAT_BRANCH_4_NAME,
+                        tgt_branch_name=DEV_BRANCH_NAME,
+                    ),
                 },
             ],
         },
@@ -323,7 +289,6 @@ def get_commits_for_git_flow_repo_w_3_release_channels() -> GetRepoDefinitionFn:
             "changelog_sections": {
                 "angular": [
                     {"section": "Bug Fixes", "i_commits": [0]},
-                    {"section": "Unknown", "i_commits": [2, 1]},
                 ],
                 "emoji": [
                     {"section": ":bug:", "i_commits": [0]},
@@ -331,51 +296,41 @@ def get_commits_for_git_flow_repo_w_3_release_channels() -> GetRepoDefinitionFn:
                 ],
                 "scipy": [
                     {"section": "Fix", "i_commits": [0]},
-                    {"section": "Unknown", "i_commits": [2, 1]},
                 ],
             },
             "commits": [
                 {
-                    "angular": {
-                        "msg": "fix(scope): correct some text",
-                        "sha": NULL_HEX_SHA,
-                    },
-                    "emoji": {
-                        "msg": ":bug: correct feature-scoped text",
-                        "sha": NULL_HEX_SHA,
-                    },
-                    "scipy": {
-                        "msg": "MAINT(scope): correct some text",
-                        "sha": NULL_HEX_SHA,
-                    },
+                    "angular": "fix(scope): correct some text",
+                    "emoji": ":bug: correct feature-scoped text",
+                    "scipy": "MAINT(scope): correct some text",
                 },
                 {
-                    "angular": {
-                        "msg": "Merge branch 'fix/patch-2' into 'dev'",
-                        "sha": NULL_HEX_SHA,
-                    },
-                    "emoji": {
-                        "msg": "Merge branch 'fix/patch-2' into 'dev'",
-                        "sha": NULL_HEX_SHA,
-                    },
-                    "scipy": {
-                        "msg": "Merge branch 'fix/patch-2' into 'dev'",
-                        "sha": NULL_HEX_SHA,
-                    },
+                    "angular": format_merge_commit_msg_git(
+                        branch_name=FIX_BRANCH_2_NAME,
+                        tgt_branch_name=DEV_BRANCH_NAME,
+                    ),
+                    "emoji": format_merge_commit_msg_git(
+                        branch_name=FIX_BRANCH_2_NAME,
+                        tgt_branch_name=DEV_BRANCH_NAME,
+                    ),
+                    "scipy": format_merge_commit_msg_git(
+                        branch_name=FIX_BRANCH_2_NAME,
+                        tgt_branch_name=DEV_BRANCH_NAME,
+                    ),
                 },
                 {
-                    "angular": {
-                        "msg": "Merge branch 'dev' into 'main'",
-                        "sha": NULL_HEX_SHA,
-                    },
-                    "emoji": {
-                        "msg": "Merge branch 'dev' into 'main'",
-                        "sha": NULL_HEX_SHA,
-                    },
-                    "scipy": {
-                        "msg": "Merge branch 'dev' into 'main'",
-                        "sha": NULL_HEX_SHA,
-                    },
+                    "angular": format_merge_commit_msg_git(
+                        branch_name=DEV_BRANCH_NAME,
+                        tgt_branch_name=DEFAULT_BRANCH_NAME,
+                    ),
+                    "emoji": format_merge_commit_msg_git(
+                        branch_name=DEV_BRANCH_NAME,
+                        tgt_branch_name=DEFAULT_BRANCH_NAME,
+                    ),
+                    "scipy": format_merge_commit_msg_git(
+                        branch_name=DEV_BRANCH_NAME,
+                        tgt_branch_name=DEFAULT_BRANCH_NAME,
+                    ),
                 },
             ],
         },
@@ -384,22 +339,9 @@ def get_commits_for_git_flow_repo_w_3_release_channels() -> GetRepoDefinitionFn:
     def _get_commits_for_git_flow_repo_w_3_release_channels(
         commit_type: CommitConvention = "angular",
     ) -> RepoDefinition:
-        definition: RepoDefinition = {}
-
-        for version, version_def in base_definition.items():
-            definition[version] = {
-                # Extract the correct changelog section header for the commit type
-                "changelog_sections": deepcopy(
-                    version_def["changelog_sections"][commit_type]
-                ),
-                "commits": [
-                    # Extract the correct commit message for the commit type
-                    deepcopy(message_variants[commit_type])
-                    for message_variants in version_def["commits"]
-                ],
-            }
-
-        return definition
+        return extract_commit_convention_from_base_repo_def(
+            base_definition, commit_type
+        )
 
     return _get_commits_for_git_flow_repo_w_3_release_channels
 
@@ -424,7 +366,14 @@ def build_git_flow_repo_w_3_release_channels(
     simulate_change_commits_n_rtn_changelog_entry: SimulateChangeCommitsNReturnChangelogEntryFn,
     simulate_default_changelog_creation: SimulateDefaultChangelogCreationFn,
     create_release_tagged_commit: CreateReleaseFn,
+    create_merge_commit: CreateMergeCommitFn,
 ) -> BuildRepoFn:
+    """
+    Builds a git-flow repository with 3 release channels (main, dev, feature)
+
+    Maintains merge commits between branches
+    """
+
     def _build_git_flow_repo_w_3_release_channels(
         dest_dir: Path | str,
         commit_type: CommitConvention = "angular",
@@ -480,7 +429,7 @@ def build_git_flow_repo_w_3_release_channels(
             )
 
             # Grab reference to the main branch
-            main_branch_head = git_repo.heads["main"]
+            main_branch_head = git_repo.heads[DEFAULT_BRANCH_NAME]
 
             # write expected Markdown changelog to this version
             simulate_default_changelog_creation(
@@ -509,13 +458,13 @@ def build_git_flow_repo_w_3_release_channels(
 
             # Change to a dev branch
             dev_branch_head = git_repo.create_head(
-                "dev", commit=main_branch_head.commit
+                DEV_BRANCH_NAME, commit=main_branch_head.commit
             )
             dev_branch_head.checkout()
 
             # Change to a feature branch
             feat_branch_head = git_repo.create_head(
-                "feat/feature-1", commit=dev_branch_head.commit
+                FEAT_BRANCH_1_NAME, commit=dev_branch_head.commit
             )
             feat_branch_head.checkout()
 
@@ -562,13 +511,13 @@ def build_git_flow_repo_w_3_release_channels(
             # checkout dev branch (in prep for merge)
             dev_branch_head.checkout()
 
-            # Merge feature branch into dev branch
-            git_repo.git.merge(
-                feat_branch_head.name,
-                no_ff=True,
-                m=next_version_def["commits"][-1]["msg"],
+            # Merge feature branch into dev branch (saving resulting definition)
+            next_version_def["commits"][-1] = create_merge_commit(
+                git_repo=git_repo,
+                branch_name=feat_branch_head.name,
+                commit_def=next_version_def["commits"][-1],
+                fast_forward=False,
             )
-            next_version_def["commits"][-1]["sha"] = git_repo.head.commit.hexsha
 
             # write expected Markdown changelog to this version
             simulate_default_changelog_creation(
@@ -597,7 +546,7 @@ def build_git_flow_repo_w_3_release_channels(
 
             # Switch to a feature branch
             feat_branch_head = git_repo.create_head(
-                "feat/feature-2", commit=dev_branch_head.commit
+                FEAT_BRANCH_2_NAME, commit=dev_branch_head.commit
             )
             feat_branch_head.checkout()
 
@@ -613,24 +562,24 @@ def build_git_flow_repo_w_3_release_channels(
             # checkout dev branch (in prep for merge)
             dev_branch_head.checkout()
 
-            # Merge feature branch into dev branch
-            git_repo.git.merge(
-                feat_branch_head.name,
-                no_ff=True,
-                m=next_version_def["commits"][-2]["msg"],
+            # Merge feature branch into dev branch (saving resulting definition)
+            next_version_def["commits"][-2] = create_merge_commit(
+                git_repo=git_repo,
+                branch_name=feat_branch_head.name,
+                commit_def=next_version_def["commits"][-2],
+                fast_forward=False,
             )
-            next_version_def["commits"][-2]["sha"] = git_repo.head.commit.hexsha
 
             # checkout main branch (in prep for merge & release)
             main_branch_head.checkout()
 
-            # Merge dev branch into main branch
-            git_repo.git.merge(
-                dev_branch_head.name,
-                no_ff=True,
-                m=next_version_def["commits"][-1]["msg"],
+            # Merge dev branch into main branch (saving resulting definition)
+            next_version_def["commits"][-1] = create_merge_commit(
+                git_repo=git_repo,
+                branch_name=dev_branch_head.name,
+                commit_def=next_version_def["commits"][-1],
+                fast_forward=False,
             )
-            next_version_def["commits"][-1]["sha"] = git_repo.head.commit.hexsha
 
             # write expected Markdown changelog to this version
             simulate_default_changelog_creation(
@@ -663,7 +612,7 @@ def build_git_flow_repo_w_3_release_channels(
 
             # Switch to a feature branch
             feat_branch_head = git_repo.create_head(
-                "feat/feature-3", commit=dev_branch_head.commit
+                FEAT_BRANCH_3_NAME, commit=dev_branch_head.commit
             )
             feat_branch_head.checkout()
 
@@ -732,17 +681,17 @@ def build_git_flow_repo_w_3_release_channels(
             # checkout dev branch (in prep for merge)
             dev_branch_head.checkout()
 
-            # Merge feature branch into dev branch
-            git_repo.git.merge(
-                feat_branch_head.name,
-                no_ff=True,
-                m=next_version_def["commits"][0]["msg"],
+            # Merge feature branch into dev branch (saving resulting definition)
+            next_version_def["commits"][0] = create_merge_commit(
+                git_repo=git_repo,
+                branch_name=feat_branch_head.name,
+                commit_def=next_version_def["commits"][0],
+                fast_forward=False,
             )
-            next_version_def["commits"][0]["sha"] = git_repo.head.commit.hexsha
 
             # Switch to a feature branch
             fix_branch_head = git_repo.create_head(
-                "fix/patch-1", commit=dev_branch_head.commit
+                FIX_BRANCH_1_NAME, commit=dev_branch_head.commit
             )
             fix_branch_head.checkout()
 
@@ -759,13 +708,13 @@ def build_git_flow_repo_w_3_release_channels(
             # checkout dev branch (in prep for merge)
             dev_branch_head.checkout()
 
-            # Merge feature branch into dev branch
-            git_repo.git.merge(
-                fix_branch_head.name,
-                no_ff=True,
-                m=next_version_def["commits"][-1]["msg"],
+            # Merge feature branch into dev branch (saving resulting definition)
+            next_version_def["commits"][-1] = create_merge_commit(
+                git_repo=git_repo,
+                branch_name=fix_branch_head.name,
+                commit_def=next_version_def["commits"][-1],
+                fast_forward=False,
             )
-            next_version_def["commits"][-1]["sha"] = git_repo.head.commit.hexsha
 
             # write expected Markdown changelog to this version
             simulate_default_changelog_creation(
@@ -794,7 +743,7 @@ def build_git_flow_repo_w_3_release_channels(
 
             # Switch to a feature branch
             feat_branch_head = git_repo.create_head(
-                "feat/feature-4", commit=dev_branch_head.commit
+                FEAT_BRANCH_4_NAME, commit=dev_branch_head.commit
             )
             feat_branch_head.checkout()
 
@@ -810,13 +759,13 @@ def build_git_flow_repo_w_3_release_channels(
             # checkout dev branch (in prep for merge)
             dev_branch_head.checkout()
 
-            # Merge feature branch into dev branch
-            git_repo.git.merge(
-                feat_branch_head.name,
-                no_ff=True,
-                m=next_version_def["commits"][-1]["msg"],
+            # Merge feature branch into dev branch (saving resulting definition)
+            next_version_def["commits"][-1] = create_merge_commit(
+                git_repo=git_repo,
+                branch_name=feat_branch_head.name,
+                commit_def=next_version_def["commits"][-1],
+                fast_forward=False,
             )
-            next_version_def["commits"][-1]["sha"] = git_repo.head.commit.hexsha
 
             # write expected Markdown changelog to this version
             simulate_default_changelog_creation(
@@ -845,7 +794,7 @@ def build_git_flow_repo_w_3_release_channels(
 
             # Switch to a fix branch
             fix_branch_head = git_repo.create_head(
-                "fix/patch-2", commit=dev_branch_head.commit
+                FIX_BRANCH_2_NAME, commit=dev_branch_head.commit
             )
             fix_branch_head.checkout()
 
@@ -861,24 +810,24 @@ def build_git_flow_repo_w_3_release_channels(
             # checkout dev branch (in prep for merge)
             dev_branch_head.checkout()
 
-            # Merge feature branch into dev branch
-            git_repo.git.merge(
-                fix_branch_head.name,
-                no_ff=True,
-                m=next_version_def["commits"][-2]["msg"],
+            # Merge feature branch into dev branch (saving resulting definition)
+            next_version_def["commits"][-2] = create_merge_commit(
+                git_repo=git_repo,
+                branch_name=fix_branch_head.name,
+                commit_def=next_version_def["commits"][-2],
+                fast_forward=False,
             )
-            next_version_def["commits"][-2]["sha"] = git_repo.head.commit.hexsha
 
             # checkout main branch (in prep for merge & release)
             main_branch_head.checkout()
 
-            # Merge dev branch into main branch
-            git_repo.git.merge(
-                dev_branch_head.name,
-                no_ff=True,
-                m=next_version_def["commits"][-1]["msg"],
+            # Merge dev branch into main branch (saving resulting definition)
+            next_version_def["commits"][-1] = create_merge_commit(
+                git_repo=git_repo,
+                branch_name=dev_branch_head.name,
+                commit_def=next_version_def["commits"][-1],
+                fast_forward=False,
             )
-            next_version_def["commits"][-1]["sha"] = git_repo.head.commit.hexsha
 
             # write expected Markdown changelog to this version
             simulate_default_changelog_creation(
@@ -971,7 +920,7 @@ def cached_repo_w_git_flow_n_3_release_channels_scipy_commits(
 
 
 @pytest.fixture
-def repo_with_git_flow_and_release_channels_angular_commits_using_tag_format(
+def repo_w_git_flow_and_release_channels_angular_commits_using_tag_format(
     cached_repo_w_git_flow_n_3_release_channels_angular_commits_tag_format: Path,
     example_project_git_repo: ExProjectGitRepoFn,
     example_project_dir: ExProjectDir,
@@ -987,7 +936,7 @@ def repo_with_git_flow_and_release_channels_angular_commits_using_tag_format(
 
 
 @pytest.fixture
-def repo_with_git_flow_and_release_channels_angular_commits(
+def repo_w_git_flow_and_release_channels_angular_commits(
     cached_repo_w_git_flow_n_3_release_channels_angular_commits: Path,
     example_project_git_repo: ExProjectGitRepoFn,
     example_project_dir: ExProjectDir,
@@ -1003,7 +952,7 @@ def repo_with_git_flow_and_release_channels_angular_commits(
 
 
 @pytest.fixture
-def repo_with_git_flow_and_release_channels_emoji_commits(
+def repo_w_git_flow_and_release_channels_emoji_commits(
     cached_repo_w_git_flow_n_3_release_channels_emoji_commits: Path,
     example_project_git_repo: ExProjectGitRepoFn,
     example_project_dir: ExProjectDir,
@@ -1019,7 +968,7 @@ def repo_with_git_flow_and_release_channels_emoji_commits(
 
 
 @pytest.fixture
-def repo_with_git_flow_and_release_channels_scipy_commits(
+def repo_w_git_flow_and_release_channels_scipy_commits(
     cached_repo_w_git_flow_n_3_release_channels_scipy_commits: Path,
     example_project_git_repo: ExProjectGitRepoFn,
     example_project_dir: ExProjectDir,
