@@ -1,6 +1,5 @@
 from __future__ import annotations
 
-from copy import deepcopy
 from typing import TYPE_CHECKING
 
 import pytest
@@ -8,7 +7,7 @@ from git import Repo
 
 from semantic_release.cli.config import ChangelogOutputFormat
 
-from tests.const import EXAMPLE_HVCS_DOMAIN, NULL_HEX_SHA
+from tests.const import EXAMPLE_HVCS_DOMAIN
 from tests.util import copy_dir_tree, temporary_working_directory
 
 if TYPE_CHECKING:
@@ -24,6 +23,7 @@ if TYPE_CHECKING:
         CommitConvention,
         CreateReleaseFn,
         ExProjectGitRepoFn,
+        ExtractRepoDefinitionFn,
         GetRepoDefinitionFn,
         GetVersionStringsFn,
         RepoDefinition,
@@ -35,40 +35,43 @@ if TYPE_CHECKING:
 
 
 @pytest.fixture(scope="session")
-def get_commits_for_trunk_only_repo_w_prerelease_tags() -> GetRepoDefinitionFn:
+def get_commits_for_trunk_only_repo_w_prerelease_tags(
+    extract_commit_convention_from_base_repo_def: ExtractRepoDefinitionFn,
+) -> GetRepoDefinitionFn:
     base_definition: dict[str, BaseRepoVersionDef] = {
         "0.1.0": {
             "changelog_sections": {
-                "angular": [{"section": "Unknown", "i_commits": [0]}],
-                "emoji": [{"section": "Other", "i_commits": [0]}],
-                "scipy": [{"section": "Unknown", "i_commits": [0]}],
-                "tag": [{"section": "Unknown", "i_commits": [0]}],
+                "angular": [{"section": "Features", "i_commits": [1]}],
+                "emoji": [
+                    {"section": ":sparkles:", "i_commits": [1]},
+                    {"section": "Other", "i_commits": [0]},
+                ],
+                "scipy": [{"section": "Feature", "i_commits": [1]}],
             },
             "commits": [
                 {
-                    "angular": {"msg": "Initial commit", "sha": NULL_HEX_SHA},
-                    "emoji": {"msg": "Initial commit", "sha": NULL_HEX_SHA},
-                    "scipy": {"msg": "Initial commit", "sha": NULL_HEX_SHA},
-                    "tag": {"msg": "Initial commit", "sha": NULL_HEX_SHA},
+                    "angular": "Initial commit",
+                    "emoji": "Initial commit",
+                    "scipy": "Initial commit",
+                },
+                {
+                    "angular": "feat: add new feature",
+                    "emoji": ":sparkles: add new feature",
+                    "scipy": "ENH: add new feature",
                 },
             ],
         },
         "0.1.1-rc.1": {
             "changelog_sections": {
-                "angular": [{"section": "Fixes", "i_commits": [0]}],
+                "angular": [{"section": "Bug Fixes", "i_commits": [0]}],
                 "emoji": [{"section": ":bug:", "i_commits": [0]}],
                 "scipy": [{"section": "Fix", "i_commits": [0]}],
-                "tag": [{"section": "Fix", "i_commits": [0]}],
             },
             "commits": [
                 {
-                    "angular": {"msg": "fix: correct some text", "sha": NULL_HEX_SHA},
-                    "emoji": {"msg": ":bug: correct some text", "sha": NULL_HEX_SHA},
-                    "scipy": {"msg": "MAINT: correct some text", "sha": NULL_HEX_SHA},
-                    "tag": {
-                        "msg": ":nut_and_bolt: correct some text",
-                        "sha": NULL_HEX_SHA,
-                    },
+                    "angular": "fix: correct some text",
+                    "emoji": ":bug: correct some text",
+                    "scipy": "MAINT: correct some text",
                 },
             ],
         },
@@ -77,20 +80,12 @@ def get_commits_for_trunk_only_repo_w_prerelease_tags() -> GetRepoDefinitionFn:
                 "angular": [{"section": "Features", "i_commits": [0]}],
                 "emoji": [{"section": ":sparkles:", "i_commits": [0]}],
                 "scipy": [{"section": "Feature", "i_commits": [0]}],
-                "tag": [{"section": "Feature", "i_commits": [0]}],
             },
             "commits": [
                 {
-                    "angular": {"msg": "feat: add some more text", "sha": NULL_HEX_SHA},
-                    "emoji": {
-                        "msg": ":sparkles: add some more text",
-                        "sha": NULL_HEX_SHA,
-                    },
-                    "scipy": {"msg": "ENH: add some more text", "sha": NULL_HEX_SHA},
-                    "tag": {
-                        "msg": ":sparkles: add some more text",
-                        "sha": NULL_HEX_SHA,
-                    },
+                    "angular": "feat: add some more text",
+                    "emoji": ":sparkles: add some more text",
+                    "scipy": "ENH: add some more text",
                 }
             ],
         },
@@ -99,20 +94,12 @@ def get_commits_for_trunk_only_repo_w_prerelease_tags() -> GetRepoDefinitionFn:
                 "angular": [{"section": "Features", "i_commits": [0]}],
                 "emoji": [{"section": ":sparkles:", "i_commits": [0]}],
                 "scipy": [{"section": "Feature", "i_commits": [0]}],
-                "tag": [{"section": "Feature", "i_commits": [0]}],
             },
             "commits": [
                 {
-                    "angular": {"msg": "feat: add some more text", "sha": NULL_HEX_SHA},
-                    "emoji": {
-                        "msg": ":sparkles: add some more text",
-                        "sha": NULL_HEX_SHA,
-                    },
-                    "scipy": {"msg": "ENH: add some more text", "sha": NULL_HEX_SHA},
-                    "tag": {
-                        "msg": ":sparkles: add some more text",
-                        "sha": NULL_HEX_SHA,
-                    },
+                    "angular": "feat: add some more text",
+                    "emoji": ":sparkles: add some more text",
+                    "scipy": "ENH: add some more text",
                 }
             ],
         },
@@ -121,22 +108,9 @@ def get_commits_for_trunk_only_repo_w_prerelease_tags() -> GetRepoDefinitionFn:
     def _get_commits_for_trunk_only_repo_w_prerelease_tags(
         commit_type: CommitConvention = "angular",
     ) -> RepoDefinition:
-        definition: RepoDefinition = {}
-
-        for version, version_def in base_definition.items():
-            definition[version] = {
-                # Extract the correct changelog section header for the commit type
-                "changelog_sections": deepcopy(
-                    version_def["changelog_sections"][commit_type]
-                ),
-                "commits": [
-                    # Extract the correct commit message for the commit type
-                    deepcopy(message_variants[commit_type])
-                    for message_variants in version_def["commits"]
-                ],
-            }
-
-        return definition
+        return extract_commit_convention_from_base_repo_def(
+            base_definition, commit_type
+        )
 
     return _get_commits_for_trunk_only_repo_w_prerelease_tags
 
@@ -357,26 +331,13 @@ def cached_repo_with_single_branch_and_prereleases_scipy_commits(
     return teardown_cached_dir(cached_repo_path)
 
 
-@pytest.fixture(scope="session")
-def cached_repo_with_single_branch_and_prereleases_tag_commits(
-    build_trunk_only_repo_w_prerelease_tags: BuildRepoFn,
-    cached_files_dir: Path,
-    teardown_cached_dir: TeardownCachedDirFn,
-) -> Path:
-    cached_repo_path = cached_files_dir.joinpath(
-        cached_repo_with_single_branch_and_prereleases_tag_commits.__name__
-    )
-    build_trunk_only_repo_w_prerelease_tags(cached_repo_path, "tag")
-    return teardown_cached_dir(cached_repo_path)
-
-
 # --------------------------------------------------------------------------- #
 # Test-level fixtures to use to set up temporary test directory               #
 # --------------------------------------------------------------------------- #
 
 
 @pytest.fixture
-def repo_with_single_branch_and_prereleases_angular_commits(
+def repo_w_trunk_only_n_prereleases_angular_commits(
     cached_repo_with_single_branch_and_prereleases_angular_commits: Path,
     example_project_git_repo: ExProjectGitRepoFn,
     example_project_dir: ExProjectDir,
@@ -392,7 +353,7 @@ def repo_with_single_branch_and_prereleases_angular_commits(
 
 
 @pytest.fixture
-def repo_with_single_branch_and_prereleases_emoji_commits(
+def repo_w_trunk_only_n_prereleases_emoji_commits(
     cached_repo_with_single_branch_and_prereleases_emoji_commits: Path,
     example_project_git_repo: ExProjectGitRepoFn,
     example_project_dir: ExProjectDir,
@@ -408,7 +369,7 @@ def repo_with_single_branch_and_prereleases_emoji_commits(
 
 
 @pytest.fixture
-def repo_with_single_branch_and_prereleases_scipy_commits(
+def repo_w_trunk_only_n_prereleases_scipy_commits(
     cached_repo_with_single_branch_and_prereleases_scipy_commits: Path,
     example_project_git_repo: ExProjectGitRepoFn,
     example_project_dir: ExProjectDir,
@@ -421,18 +382,3 @@ def repo_with_single_branch_and_prereleases_scipy_commits(
         example_project_dir,
     )
     return example_project_git_repo()
-
-
-@pytest.fixture
-def repo_with_single_branch_and_prereleases_tag_commits(
-    cached_repo_with_single_branch_and_prereleases_tag_commits: Path,
-    example_project_git_repo: ExProjectGitRepoFn,
-    example_project_dir: ExProjectDir,
-    change_to_ex_proj_dir: None,
-) -> Repo:
-    if not cached_repo_with_single_branch_and_prereleases_tag_commits.exists():
-        raise RuntimeError("Unable to find cached repository!")
-    copy_dir_tree(
-        cached_repo_with_single_branch_and_prereleases_tag_commits, example_project_dir
-    )
-    return example_project_git_repo()
